@@ -2,6 +2,7 @@ use std::cell::RefCell;
 use std::ffi::c_void;
 use std::ffi::CStr;
 use std::ffi::CString;
+use std::os::raw::c_char;
 
 struct Person {
     name: String,
@@ -33,8 +34,8 @@ type CPerson = c_void;
 
 #[no_mangle]
 pub extern "C" fn person_new(
-    _class: *const i8,
-    name: *const i8,
+    _class: *const c_char,
+    name: *const c_char,
     lucky_number: i32,
 ) -> *mut CPerson {
     let name = unsafe { CStr::from_ptr(name) };
@@ -43,7 +44,7 @@ pub extern "C" fn person_new(
 }
 
 #[no_mangle]
-pub extern "C" fn person_name(p: *mut CPerson) -> *const i8 {
+pub extern "C" fn person_name(p: *mut CPerson) -> *const c_char {
     thread_local!(
         static KEEP: RefCell<Option<CString>> = RefCell::new(None);
     );
@@ -58,7 +59,7 @@ pub extern "C" fn person_name(p: *mut CPerson) -> *const i8 {
 }
 
 #[no_mangle]
-pub extern "C" fn person_rename(p: *mut CPerson, new: *const i8) {
+pub extern "C" fn person_rename(p: *mut CPerson, new: *const c_char) {
     let new = unsafe { CStr::from_ptr(new) };
     let p = unsafe { &mut *(p as *mut Person) };
     if let Ok(new) = new.to_str() {
